@@ -30,7 +30,7 @@
 
 #include "mdadm.h"
 
-char Version[] = Name " - v2.3.1 - 6 February 2006\n";
+char Version[] = Name " - v2.4.1 -  4 April 2006\n";
 
 /*
  * File: ReadMe.c
@@ -172,6 +172,8 @@ struct option long_options[] = {
     {"daemonize", 0, 0, 'f'},
     {"oneshot",   0, 0, '1'},
     {"pid-file",  1, 0, 'i'},
+    /* For Grow */
+    {"backup-file", 1,0, 7},
     
     {0, 0, 0, 0}
 };
