@@ -229,7 +229,7 @@ int check_reiser(int fd, char *name)
 	 *
 	 */
 	unsigned char sb[1024];
-	int size;
+	unsigned long size;
 	if (lseek(fd, 64*1024, 0) != 64*1024)
 		return 0;
 	if (read(fd, sb, 1024) != 1024)
@@ -239,7 +239,7 @@ int check_reiser(int fd, char *name)
 		return 0;
 	fprintf(stderr, Name ": %s appears to contain a reiserfs file system\n",name);
 	size = sb[0]|(sb[1]|(sb[2]|sb[3]<<8)<<8)<<8;
-	fprintf(stderr, "    size = %dK\n", size*4);
+	fprintf(stderr, "    size = %luK\n", size*4);
 		
 	return 1;
 }
@@ -248,7 +248,6 @@ int check_raid(int fd, char *name)
 {
 	void *super;
 	struct mdinfo info;
-	struct mddev_ident_s ident;
 	time_t crtime;
 	char *level;
 	struct supertype *st = guess_super(fd);
@@ -258,7 +257,7 @@ int check_raid(int fd, char *name)
 	/* Looks like a raid array .. */
 	fprintf(stderr, Name ": %s appears to be part of a raid array:\n",
 		name);
-	st->ss->getinfo_super(&info, &ident, super);
+	st->ss->getinfo_super(&info, super);
 	free(super);
 	crtime = info.array.ctime;
 	level = map_num(pers, info.array.level);
@@ -359,7 +358,7 @@ int devlist_ready = 0;
 int add_dev(const char *name, const struct stat *stb, int flag, struct FTW *s)
 {
 }
-char *map_dev(int major, int minor)
+char *map_dev(int major, int minor, int create)
 {
 #if 0
 	fprintf(stderr, "Warning - fail to map %d,%d to a device name\n",
@@ -382,18 +381,26 @@ int nftw(const char *path, int (*han)(const char *name, const struct stat *stb,
 
 int add_dev(const char *name, const struct stat *stb, int flag, struct FTW *s)
 {
-    if ((stb->st_mode&S_IFMT)== S_IFBLK) {
-	char *n = strdup(name);
-	struct devmap *dm = malloc(sizeof(*dm));
-	if (dm) {
-	    dm->major = major(stb->st_rdev);
-	    dm->minor = minor(stb->st_rdev);
-	    dm->name = n;
-	    dm->next = devlist;
-	    devlist = dm;
+	struct stat st;
+	if (S_ISLNK(stb->st_mode)) {
+		stat(name, &st);
+		stb = &st;
 	}
-    }
-    return 0;
+
+	if ((stb->st_mode&S_IFMT)== S_IFBLK) {
+		char *n = strdup(name);
+		struct devmap *dm = malloc(sizeof(*dm));
+		if (strncmp(n, "/dev/./", 7)==0)
+			strcpy(n+4, name+6);
+		if (dm) {
+			dm->major = major(stb->st_rdev);
+			dm->minor = minor(stb->st_rdev);
+			dm->name = n;
+			dm->next = devlist;
+			devlist = dm;
+		}
+	}
+	return 0;
 }
 
 /*
@@ -403,12 +410,17 @@ int add_dev(const char *name, const struct stat *stb, int flag, struct FTW *s)
  * deliberately so prefer it over a standard name.
  * This applies only to names for MD devices.
  */
-char *map_dev(int major, int minor)
+char *map_dev(int major, int minor, int create)
 {
 	struct devmap *p;
 	char *std = NULL, *nonstd=NULL;
 	if (!devlist_ready) {
-		nftw("/dev", add_dev, 10, FTW_PHYS);
+		char *dev = "/dev";
+		struct stat stb;
+		if (lstat(dev, &stb)==0 &&
+		    S_ISLNK(stb.st_mode))
+			dev = "/dev/.";
+		nftw(dev, add_dev, 10, FTW_PHYS);
 		devlist_ready=1;
 	}
 
@@ -425,6 +437,12 @@ char *map_dev(int major, int minor)
 					nonstd = p->name;
 			}
 		}
+	if (create && !std && !nonstd) {
+		static char buf[30];
+		snprintf(buf, 1024, "%d:%d", major, minor);
+		nonstd = buf;
+	}
+
 	return nonstd ? nonstd : std;
 }
 
@@ -567,7 +585,7 @@ char *get_md_name(int dev)
 		    && (stb.st_rdev == rdev))
 			return devname;
 	}
-	dn = map_dev(major(rdev), minor(rdev));
+	dn = map_dev(major(rdev), minor(rdev), 0);
 	if (dn)
 		return dn;
 	snprintf(devname, sizeof(devname), "/dev/.tmp.md%d", dev);
@@ -653,8 +671,7 @@ struct supertype *guess_super(int fd)
 		rv = ss->load_super(st, fd, &sbp, NULL);
 		if (rv == 0) {
 			struct mdinfo info;
-			struct mddev_ident_s ident;
-			ss->getinfo_super(&info, &ident, sbp);
+			ss->getinfo_super(&info, sbp);
 			if (bestsuper == -1 ||
 			    besttime < info.array.ctime) {
 				bestsuper = i;
@@ -676,6 +693,7 @@ struct supertype *guess_super(int fd)
 	return NULL;
 }
 
+
 #ifdef __TINYC__
 /* tinyc doesn't optimize this check in ioctl.h out ... */
 unsigned int __invalid_size_argument_for_IOC = 0;
